A new {mod}`anndata.io` module contains all `read_*` and `write_*` functions, and all imports of such functions should go through this module.
Old ways of importing these functions i.e., `from anndata import read_csv` or `from anndata._io.specs import read_elem` will still work, but are now considered deprecated and give a warning on import with the exception of {func}`anndata.io.read_zarr` and {func}`anndata.io.read_h5ad`, which will remain at the top-level `anndata` without warning.  `user`{ilan-gold}
